# SDLE FAIR Package: Centralized Entity Mapping & Extraction Nexus for Triples and Ontologies (CEMENTO)

**Description:**

This package is part of the larger SDLE FAIR application suite that features tools to create scientific ontologies faster and more efficiently. This package can provide OOP interfaces for drawing and reading ontology diagrams made using draw.io. The code is able to generate a list of relationship triples that are used to store and construct ontology diagrams.

## Installation

To install this particular package, use pip to install the latest version of the package:

```{bash}
pip install cemento
```

## Usage

One can refer to the examples folder for sample implementations of basic read and write operations with draw.io diagrams. Please run the examples while in the root folder of the repository.

## License

This project was released under the BSD-3-Clause License. For more information about the license and the Open Source movement, please check the [Open Source Initiative](https://opensource.org/licenses) website.

## Contact Information
If you have any questions or need further assistance, feel free to contact us at:

Email: 
[gop2@case.edu](Gabriel Obsequio Ponon)